# Python

The Launchable CLI includes built-in integrations for test runners and build tools that are popular in the Python ecosystem:

* [nose](../integrations/nose.md)
* [pytest](../integrations/pytest.md)

See each integration's page for instructions to add Launchable to your CI pipeline.
